@@ -5,8 +5,8 @@
 * Botan is released under the Simplified BSD License (see license.txt)
 */
 
-#ifndef BOTAN_ADLER32_H__
-#define BOTAN_ADLER32_H__
+#ifndef BOTAN_ADLER32_H_
+#define BOTAN_ADLER32_H_
 
 #include <botan/hash.h>
 
@@ -15,7 +15,7 @@ namespace Botan {
 /**
 * The Adler32 checksum, used in zlib
 */
-class BOTAN_DLL Adler32 final : public HashFunction
+class BOTAN_PUBLIC_API(2,0) Adler32 final : public HashFunction
    {
    public:
       std::string name() const override { return "Adler32"; }
