@@ -5,19 +5,20 @@
 * Botan is released under the Simplified BSD License (see license.txt)
 */
 
-#ifndef BOTAN_ALGORITHM_IDENTIFIER_H__
-#define BOTAN_ALGORITHM_IDENTIFIER_H__
+#ifndef BOTAN_ALGORITHM_IDENTIFIER_H_
+#define BOTAN_ALGORITHM_IDENTIFIER_H_
 
 #include <botan/asn1_obj.h>
 #include <botan/asn1_oid.h>
 #include <string>
+#include <vector>
 
 namespace Botan {
 
 /**
 * Algorithm Identifier
 */
-class BOTAN_DLL AlgorithmIdentifier final : public ASN1_Object
+class BOTAN_PUBLIC_API(2,0) AlgorithmIdentifier final : public ASN1_Object
    {
    public:
       enum Encoding_Option { USE_NULL_PARAM };
@@ -42,9 +43,9 @@ class BOTAN_DLL AlgorithmIdentifier final : public ASN1_Object
 /*
 * Comparison Operations
 */
-bool BOTAN_DLL operator==(const AlgorithmIdentifier&,
+bool BOTAN_PUBLIC_API(2,0) operator==(const AlgorithmIdentifier&,
                           const AlgorithmIdentifier&);
-bool BOTAN_DLL operator!=(const AlgorithmIdentifier&,
+bool BOTAN_PUBLIC_API(2,0) operator!=(const AlgorithmIdentifier&,
                           const AlgorithmIdentifier&);
 
 }
