@@ -9,8 +9,9 @@
 #define BOTAN_X509_SELF_H_
 
 #include <botan/x509cert.h>
+#include <botan/x509_ext.h>
 #include <botan/pkcs10.h>
-#include <botan/pkix_types.h>
+#include <botan/asn1_time.h>
 
 namespace Botan {
 
@@ -43,11 +44,6 @@ class BOTAN_PUBLIC_API(2,0) X509_Cert_Options final
       */
       std::string org_unit;
 
-      /**
-       * additional subject organizational units.
-       */
-      std::vector<std::string> more_org_units;
-
       /**
       * the subject locality
       */
@@ -83,11 +79,6 @@ class BOTAN_PUBLIC_API(2,0) X509_Cert_Options final
       */
       std::string dns;
 
-      /**
-       * additional subject DNS entries.
-       */
-      std::vector<std::string> more_dns;
-
       /**
       * the subject XMPP
       */
@@ -117,8 +108,6 @@ class BOTAN_PUBLIC_API(2,0) X509_Cert_Options final
       */
       size_t path_limit;
 
-      std::string padding_scheme;
-
       /**
       * The key constraints for the subject public key
       */
@@ -140,11 +129,6 @@ class BOTAN_PUBLIC_API(2,0) X509_Cert_Options final
       */
       void CA_key(size_t limit = 1);
 
-      /**
-      * Choose a padding scheme different from the default for the key used.
-      */
-      void set_padding_scheme(const std::string& scheme);
-
       /**
       * Set the notBefore of the certificate.
       * @param time the notBefore value of the certificate
