@@ -5,17 +5,10 @@
  * Botan is released under the Simplified BSD License (see license.txt)
  **/
 
-#ifndef BOTAN_XMSS_INDEX_REGISTRY_H__
-#define BOTAN_XMSS_INDEX_REGISTRY_H__
+#ifndef BOTAN_XMSS_INDEX_REGISTRY_H_
+#define BOTAN_XMSS_INDEX_REGISTRY_H_
 
-#include <stdint.h>
-#include <cstddef>
-#include <limits>
-#include <memory>
-#include <string>
-#include <botan/hash.h>
 #include <botan/secmem.h>
-#include <botan/types.h>
 #include <botan/atomic.h>
 #include <botan/mutex.h>
 
